Python: module share

share (version 0.1.0) | index share.py

`This tool run scripts and display the result in a Web Interface.
This file download and upload functions for scripts,
tools and command line client.`

Modules
`` |  |
ntpath |  |  |

Classes
`` |  | builtins.object Download
class Download(builtins.object)
`` | `This class implement download functions for filename or ID.`
| Methods defined here: filename(environ: os._Environ, user: ~User, server_configuration: ~ServerConfiguration, filename: str, arguments: List[str], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This funtion download file by filename.` id(environ: os._Environ, user: ~User, server_configuration: ~ServerConfiguration, id_: str, arguments: List[str], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This funtion download file by ID.` Static methods defined here: get_data(file: uploads_management.Upload) -> bytes `This function get file and manage the compression.` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`

Functions
`` |  | upload(environ: os._Environ, user: ~User, server_configuration: ~ServerConfiguration, filename: str, data: bytes, none: None, csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This funtion upload file.`

Data
`` |  | Dict = typing.Dict List = typing.List ServerConfiguration = ~ServerConfiguration Tuple = typing.Tuple User = ~User __author_email__ = 'mauricelambert434@gmail.com' __copyright__ = '\nWebScripts Copyright (C) 2021, 2022 Maurice L...ome to redistribute it\nunder certain conditions.\n' __description__ = '\nThis tool run scripts and display the result in...tions for scripts,\ntools and command line client.' __license__ = 'GPL-3.0 License' __maintainer__ = 'Maurice Lambert' __maintainer_email__ = 'mauricelambert434@gmail.com' __url__ = 'https://github.com/mauricelambert/WebScripts' copyright = '\nWebScripts Copyright (C) 2021, 2022 Maurice L...ome to redistribute it\nunder certain conditions.\n' env = environ({'ALLUSERSPROFILE': 'C:\\ProgramData', '...\\CSU1\\go\\bin', '_OLD_VIRTUAL_PROMPT': '$P$G'}) license = 'GPL-3.0 License' syspath = [r'/home/WebScripts\scripts\doc', r'C:\Program Files\Python\python39.zip', r'C:\Program Files\Python\DLLs', r'C:\Program Files\Python\lib', r'C:\Program Files\Python', r'C:\Users\CSU1\Documents\dev\test', r'C:\Users\CSU1\Documents\dev\test\lib\site-packages', r'c:\users\csu1\documents\dev\modules\webscripts', r'C:\Users\CSU1\Documents\dev\test\lib\site-packages\win32', r'C:\Users\CSU1\Documents\dev\test\lib\site-packages\win32\lib', r'C:\Users\CSU1\Documents\dev\test\lib\site-packages\Pythonwin', r'/home/WebScripts\modules']

Author
`` |  | Maurice Lambert